@@ -455,7 +455,7 @@ def do_lc(tpf,ts,splits,sub,maxiter=101,split_times=None,w_init=None,random_init
         "initial_cadence": cad1,
         "final_cadence": cad2,
         "sat_pixels": sat,
-        "weightmap": weightmap
+        "weightmap": weightmap[0]
         }
         ts = stitch(tss)
         
@@ -516,18 +516,20 @@ def do_lc(tpf,ts,splits,sub,maxiter=101,split_times=None,w_init=None,random_init
             print('Calculated weights!')
 
         ts['corr_flux'] = np.nan*np.ones_like(ts['x'])
-        ts['corr_flux'][goodcad] = opt_lc
+        ts['corr_flux'][goodcad] = opt_lc/np.nanmedian(opt_lc)
 
         if sub == 1:
             pixelmap.ravel()[mapping] = weights
         else:
             pixelmap.ravel()[mapping[0][::sub]] = weights
+
         wmap = {
         "initial_cadence": c1,
         "final_cadence": c2,
         "sat_pixels": sat,
         "weightmap": pixelmap
         }
+
     return tpf, ts, weights, wmap, pixels_sub
 
 # =========================================================================
@@ -1149,14 +1151,16 @@ class halo_tpf(lightkurve.KeplerTargetPixelFile):
                 'ra':self.ra,
                 'dec':self.dec,
                 'cadenceno':ts['cadence']}
+
         lc_out = lightkurve.KeplerLightCurve(flux=ts['corr_flux'],
                                 time=Time(ts['time'],format=self.time.format),
                                 flux_err=np.nan*ts['corr_flux'],
                                 **keys)
         lc_out.pos_corr1 = self.pos_corr1
         lc_out.pos_corr2 = self.pos_corr2
-        lc_out.primary_header = self.hdu[0].header
-        lc_out.data_header = self.hdu[1].header
+        hdu  = lc_out.to_fits() 
+        lc_out.primary_header = hdu[0].header
+        lc_out.data_header = hdu[1].header
         return weightmap, lc_out
 
 class halo_tpf_tess(lightkurve.TessTargetPixelFile):
